[Xfce4-commits] [xfce/thunar] 01/01: Fix typo in error message.

noreply at xfce.org noreply at xfce.org
Thu Feb 19 18:00:10 CET 2015


This is an automated email from the git hooks/post-receive script.

nick pushed a commit to branch master
in repository xfce/thunar.

commit 9ce64a0a20766d76d80162ab0e4b44f2761870a0
Author: Nick Schermer <nick at xfce.org>
Date:   Thu Feb 19 17:59:57 2015 +0100

    Fix typo in error message.
---
 thunar/thunar-dbus-service.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/thunar/thunar-dbus-service.c b/thunar/thunar-dbus-service.c
index 929f6c4..b908a7a 100644
--- a/thunar/thunar-dbus-service.c
+++ b/thunar/thunar-dbus-service.c
@@ -238,7 +238,7 @@ thunar_dbus_service_class_init (ThunarDBusServiceClass *klass)
   /**
    * ThunarDBusService::trash-changed:
    * @dbus_service : a #ThunarDBusService.
    * @full         : %TRUE if the trash bin now contains atleast
    *                 one item, %FALSE otherwise.
    *
    * This signal is emitted whenever the state of the trash bin
@@ -875,11 +875,11 @@ thunar_dbus_service_launch_files (ThunarDBusService *dbus_service,
       return FALSE;
     }
 
   /* verify that atleast one filename is given */
   if (G_UNLIKELY (filenames == NULL || *filenames == NULL))
     {
       /* LaunchFiles() invoked with an empty filename list */
-      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, _("Atleast one filename must be specified"));
+      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, _("At least one filename must be specified"));
       return FALSE;
     }
 
@@ -238,7 +238,7 @@ thunar_dbus_service_class_init (ThunarDBusServiceClass *klass)
    * ThunarDBusService::trash-changed:
    * @dbus_service : a #ThunarDBusService.
-   * @full         : %TRUE if the trash bin now contains atleast
+   * @full         : %TRUE if the trash bin now contains at least
    *                 one item, %FALSE otherwise.
    *
@@ -875,11 +875,11 @@ thunar_dbus_service_launch_files (ThunarDBusService *dbus_service,
     }
 
-  /* verify that atleast one filename is given */
+  /* verify that at least one filename is given */
   if (G_UNLIKELY (filenames == NULL || *filenames == NULL))
     {

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list